==> pyegeria-0.5.2.tar.gz: pyegeria-0.5.2/pyegeria/core_guids.py <==
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Useful from core content archive
"""

#
# Template guids
#

CSV_DATA_FILE_TEMPLATE_GUID = '13770F93-13C8-42BE-9BB8-E0B1B1E52B1F'

KEYSTORE_FILE_TEMPLATE_GUID = 'FBCFCC0C-1652-421F-B49B-C3E1C108768F'

OSS_UNITY_CATALOG_FUNCTION_TEMPLATE_GUID = '4AE9F6DF-4678-4B0A-A492-4A982C8397FD'

DATA_FILE_TEMPLATE_GUID = '66D8DDA9-00CF-4E59-938C-4B0583596B1E'

VIEW_SERVER_TEMPLATE_GUID = 'FD61CA01-390D-4AA2-A55D-426826AA4E1B'

ARCHIVE_FILE_TEMPLATE_GUID = '7578E504-D00F-406D-A194-3FC0A351CDF9'

POSTGRESQL_RELATIONAL_DATABASE_TEMPLATE_GUID = '3D398B3F-7AE6-4713-952A-409F3DEA8520'

OSS_UNITY_CATALOG_VOLUME_TEMPLATE_GUID = '384386BA-83C0-4981-8553-4306AECE440F'

PROGRAM_FILE_TEMPLATE_GUID = '32D27E9C-1FDF-455A-AD2A-42B4D7D99108'

FILEFOLDER_TEMPLATE_GUID = 'FBDD8EFD-1B69-474C-BB6D-0A304B394146'

OSS_UNITY_CATALOG_CATALOG_TEMPLATE_GUID = 'F7B05A3E-913C-497D-96F5-ACDEB2EC897E'

POSTGRESQL_SERVER_TEMPLATE_GUID = '542134E6-B9CE-4DCE-8AEF-22E8DAF34FDB'

AUDIO_DATA_FILE_TEMPLATE_GUID = '39B4B670-7F15-4744-A5BA-62E8EDAFBCEE'

DOCUMENT_FILE_TEMPLATE_GUID = 'EB6F728D-FA54-4350-9807-1199CBF96851'

INTEGRATION_DAEMON_TEMPLATE_GUID = '6B3516F0-DD13-4786-9601-07215F995197'

XML_DATA_FILE_TEMPLATE_GUID = 'EA67AE71-C674-473E-B38B-689879D2A7D9'

PARQUET_DATA_FILE_TEMPLATE_GUID = '7F6CD744-79C3-4D25-A056-EEB1A91574C3'

THREED_IMAGE_DATA_FILE_TEMPLATE_GUID = '0059EA2B-6292-4CAC-AA6F-A80A605F1114'

YAML_FILE_TEMPLATE_GUID = '2221855B-2B64-4B45-A2EE-C40ADC5E2A64'

METADATA_ACCESS_SERVER_TEMPLATE_GUID = 'BD8DE890-FA79-4C24-AAB8-20B41B5893DD'

PROPERTIES_FILE_TEMPLATE_GUID = '3B281111-A0EF-4FC4-99E7-9A0EF84A7636'

VECTOR_DATA_FILE_TEMPLATE_GUID = 'DB1BEC7F-55A9-40D3-91C0-A57B76D422E2'

APACHE_KAFKA_SERVER_TEMPLATE_GUID = '5E1FF810-5418-43F7-B7C4-E6E062F9AFF7'

OSS_UNITY_CATALOG_SCHEMA_TEMPLATE_GUID = 'A75CFB07-31FE-457E-9298-BE145DC93071'

EXECUTABLE_FILE_TEMPLATE_GUID = '3D99A163-7A13-4576-A212-784010A8302A'

JSON_DATA_FILE_TEMPLATE_GUID = 'C4836635-7E9E-446A-83B5-15E206B1AFF3'

FILE_SYSTEM_TEMPLATE_GUID = '522F228C-097C-4F90-9EFC-26C1F2696F87'

SOURCE_CODE_FILE_TEMPLATE_GUID = '9C7013EF-F29B-4B01-A8EA-5EA14F64C67A'

OSS_UNITY_CATALOG_SERVER_TEMPLATE_GUID = '1077A346-7A50-4CB0-A795-B219BAFAABF6'

APPLE_MACBOOK_PRO_TEMPLATE_GUID = '32A9FD56-85C9-47FE-A211-9DA3871BF4DA'

BUILD_INSTRUCTION_FILE_TEMPLATE_GUID = 'FBB2FA2E-8BCB-402E-9BE7-5C6DB9F2C504'

SPREADSHEET_DATA_FILE_TEMPLATE_GUID = 'E4FABFF5-2BA9-4050-9076-6ED917970B4C'

UNIX_FILE_SYSTEM_TEMPLATE_GUID = '27117270-8667-41D0-A99A-9118F9B60199'

VIDEO_DATA_FILE_TEMPLATE_GUID = '93B2B722-EC0F-4DA4-960A-B8D4922F8BF5'

POSTGRESQL_RELATIONAL_DATABASE_SCHEMA_TEMPLATE_GUID = '82A5417C-D882-4271-8444-4C6A996A8BFC'

ENGINE_HOST_TEMPLATE_GUID = '1764A891-4234-45F1-8CC3-536AF40C790D'

AVRO_DATA_FILE_TEMPLATE_GUID = '9F5BE428-058E-41DD-B506-3A222283B579'

OSS_UNITY_CATALOG_TABLE_TEMPLATE_GUID = 'F5B12348-92AC-4A52-B8E0-B06CF215484E'

FILE_TEMPLATE_GUID = 'AE3067C7-CC72-4A18-88E1-746803C2C86F'

APACHE_KAFKA_TOPIC_TEMPLATE_GUID = 'EA8F81C9-C59C-47DE-9525-7CC59D1251E5'

SCRIPT_FILE_TEMPLATE_GUID = 'DBD5E6BB-1FF8-46F4-A007-FB0485F68C92'

APACHE_ATLAS_SERVER_TEMPLATE_GUID = 'FE6DCE45-A978-4417-AB55-17F05B8BCEA7'

RASTER_DATA_FILE_TEMPLATE_GUID = '47211156-F03F-4881-8526-015E695A3DAC'

DATA_FOLDER_TEMPLATE_GUID = '372A0379-7060-4C9D-8D84-BC709B31794C'

OMAG_SERVER_PLATFORM_TEMPLATE_GUID = '9B06C4DC-DDC8-47AE-B56B-28775D3A96F0'

#
# Integration Connector GUIDS
#

PostgreSQL_Relational_Database_Integration_Connector_GUID = '70dcd0b7-9f06-48ad-ad44-ae4d7a7762aa'

Landing_Area_File_Monitor_Integration_Connector_GUID = '1b98cdac-dd0a-4621-93db-99ef5a1098bc'

FileFolder_Integration_Connector_GUID = 'cd6479e1-2fe7-4426-b358-8a0cf70be117'

OSS_Unity_Catalog_Catalog_Integration_Connector_GUID = '74dde22f-2249-4ea3-af2b-b39e73f79b81'

PostgreSQL_Server_Integration_Connector_GUID = '36f69fd0-54ba-4f59-8a44-11ccf2687a34'

Apache_Kafka_Server_Integration_Connector_GUID = 'fa1f711c-0b34-4b57-8e6e-16162b132b0c'

Software_Server_Integration_Connector_GUID = 'b89d9a5a-2ea6-49bc-a4fc-e7df9f3ca93e'

OSS_Unity_Catalog_Server_Integration_Connector_GUID = '06d068d9-9e08-4e67-8c59-073bbf1013af'

==> pyegeria-0.5.5.10.tar.gz: pyegeria-0.5.5.10/pyegeria/core_guids.py <==
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Useful from core content archive
"""

#
# Template guids
#

CSV_DATA_FILE_TEMPLATE_GUID = '13770F93-13C8-42BE-9BB8-E0B1B1E52B1F'

KEYSTORE_FILE_TEMPLATE_GUID = 'FBCFCC0C-1652-421F-B49B-C3E1C108768F'

OSS_UNITY_CATALOG_FUNCTION_TEMPLATE_GUID = '5B72BD18-665D-4696-8EBB-F6D0885312E2'

DATA_FILE_TEMPLATE_GUID = '66D8DDA9-00CF-4E59-938C-4B0583596B1E'

VIEW_SERVER_TEMPLATE_GUID = 'FD61CA01-390D-4AA2-A55D-426826AA4E1B'

ARCHIVE_FILE_TEMPLATE_GUID = '7578E504-D00F-406D-A194-3FC0A351CDF9'

POSTGRESQL_RELATIONAL_DATABASE_TEMPLATE_GUID = '3D398B3F-7AE6-4713-952A-409F3DEA8520'

OSS_UNITY_CATALOG_VOLUME_TEMPLATE_GUID = 'DFC0C928-0DB3-4EB4-A1F0-0760DAB168C5'

PROGRAM_FILE_TEMPLATE_GUID = '32D27E9C-1FDF-455A-AD2A-42B4D7D99108'

FILEFOLDER_TEMPLATE_GUID = 'FBDD8EFD-1B69-474C-BB6D-0A304B394146'

OSS_UNITY_CATALOG_CATALOG_TEMPLATE_GUID = 'F7B05A3E-913C-497D-96F5-ACDEB2EC897E'

POSTGRESQL_SERVER_TEMPLATE_GUID = '542134E6-B9CE-4DCE-8AEF-22E8DAF34FDB'

AUDIO_DATA_FILE_TEMPLATE_GUID = '39B4B670-7F15-4744-A5BA-62E8EDAFBCEE'

DOCUMENT_FILE_TEMPLATE_GUID = 'EB6F728D-FA54-4350-9807-1199CBF96851'

INTEGRATION_DAEMON_TEMPLATE_GUID = '6B3516F0-DD13-4786-9601-07215F995197'

XML_DATA_FILE_TEMPLATE_GUID = 'EA67AE71-C674-473E-B38B-689879D2A7D9'

PARQUET_DATA_FILE_TEMPLATE_GUID = '7F6CD744-79C3-4D25-A056-EEB1A91574C3'

THREED_IMAGE_DATA_FILE_TEMPLATE_GUID = '0059EA2B-6292-4CAC-AA6F-A80A605F1114'

YAML_FILE_TEMPLATE_GUID = '2221855B-2B64-4B45-A2EE-C40ADC5E2A64'

METADATA_ACCESS_SERVER_TEMPLATE_GUID = 'BD8DE890-FA79-4C24-AAB8-20B41B5893DD'

PROPERTIES_FILE_TEMPLATE_GUID = '3B281111-A0EF-4FC4-99E7-9A0EF84A7636'

VECTOR_DATA_FILE_TEMPLATE_GUID = 'DB1BEC7F-55A9-40D3-91C0-A57B76D422E2'

APACHE_KAFKA_SERVER_TEMPLATE_GUID = '5E1FF810-5418-43F7-B7C4-E6E062F9AFF7'

OSS_UNITY_CATALOG_SCHEMA_TEMPLATE_GUID = 'D68F5AA3-152E-40FA-8C16-E73DB8D925D6'

EXECUTABLE_FILE_TEMPLATE_GUID = '3D99A163-7A13-4576-A212-784010A8302A'

JSON_DATA_FILE_TEMPLATE_GUID = 'C4836635-7E9E-446A-83B5-15E206B1AFF3'

FILE_SYSTEM_TEMPLATE_GUID = '522F228C-097C-4F90-9EFC-26C1F2696F87'

SOURCE_CODE_FILE_TEMPLATE_GUID = '9C7013EF-F29B-4B01-A8EA-5EA14F64C67A'

OSS_UNITY_CATALOG_SERVER_TEMPLATE_GUID = '1077A346-7A50-4CB0-A795-B219BAFAABF6'

APPLE_MACBOOK_PRO_TEMPLATE_GUID = '32A9FD56-85C9-47FE-A211-9DA3871BF4DA'

OSS_UNITY_CATALOG_TABLE_TEMPLATE_GUID = 'CB34184B-D6A9-4A27-9FD2-EA4C78978F9F'

BUILD_INSTRUCTION_FILE_TEMPLATE_GUID = 'FBB2FA2E-8BCB-402E-9BE7-5C6DB9F2C504'

SPREADSHEET_DATA_FILE_TEMPLATE_GUID = 'E4FABFF5-2BA9-4050-9076-6ED917970B4C'

UNIX_FILE_SYSTEM_TEMPLATE_GUID = '27117270-8667-41D0-A99A-9118F9B60199'

VIDEO_DATA_FILE_TEMPLATE_GUID = '93B2B722-EC0F-4DA4-960A-B8D4922F8BF5'

POSTGRESQL_RELATIONAL_DATABASE_SCHEMA_TEMPLATE_GUID = '82A5417C-D882-4271-8444-4C6A996A8BFC'

ENGINE_HOST_TEMPLATE_GUID = '1764A891-4234-45F1-8CC3-536AF40C790D'

AVRO_DATA_FILE_TEMPLATE_GUID = '9F5BE428-058E-41DD-B506-3A222283B579'

FILE_TEMPLATE_GUID = 'AE3067C7-CC72-4A18-88E1-746803C2C86F'

APACHE_KAFKA_TOPIC_TEMPLATE_GUID = 'EA8F81C9-C59C-47DE-9525-7CC59D1251E5'

SCRIPT_FILE_TEMPLATE_GUID = 'DBD5E6BB-1FF8-46F4-A007-FB0485F68C92'

APACHE_ATLAS_SERVER_TEMPLATE_GUID = 'FE6DCE45-A978-4417-AB55-17F05B8BCEA7'

RASTER_DATA_FILE_TEMPLATE_GUID = '47211156-F03F-4881-8526-015E695A3DAC'

DATA_FOLDER_TEMPLATE_GUID = '372A0379-7060-4C9D-8D84-BC709B31794C'

OMAG_SERVER_PLATFORM_TEMPLATE_GUID = '9B06C4DC-DDC8-47AE-B56B-28775D3A96F0'

#
# Integration Connector GUIDS
#



JDBC_RELATIONAL_DATABASE_INTEGRATION_CONNECTOR_GUID = '70DCD0B7-9F06-48AD-AD44-AE4D7A7762AA'

POSTGRESQL_RELATIONAL_DATABASE_INTEGRATION_CONNECTOR_GUID = '70DCD0B7-9F06-48AD-AD44-AE4D7A7762AA'

LANDING_AREA_FILE_MONITOR_INTEGRATION_CONNECTOR_GUID = '1B98CDAC-DD0A-4621-93DB-99EF5A1098BC'

FILEFOLDER_INTEGRATION_CONNECTOR_GUID = 'CD6479E1-2FE7-4426-B358-8A0CF70BE117'

OSS_UNITY_CATALOG_CATALOG_INTEGRATION_CONNECTOR_GUID = '74DDE22F-2249-4EA3-AF2B-B39E73F79B81'

POSTGRESQL_SERVER_INTEGRATION_CONNECTOR_GUID = '36F69FD0-54BA-4F59-8A44-11CCF2687A34'

APACHE_KAFKA_SERVER_INTEGRATION_CONNECTOR_GUID = 'FA1F711C-0B34-4B57-8E6E-16162B132B0C'

SOFTWARE_SERVER_INTEGRATION_CONNECTOR_GUID = 'B89D9A5A-2EA6-49BC-A4FC-E7DF9F3CA93E'

OSS_UNITY_CATALOG_SERVER_INTEGRATION_CONNECTOR_GUID = '06D068D9-9E08-4E67-8C59-073BBF1013AF'
